import greenfoot.*;

/**
 * A rocket that can be controlled by the arrowkeys: up, left, right.
 * The gun is fired by hitting the 'space' key. 'z' releases a proton wave.
 * 
 * @author Poul Henriksen
 * @author Michael Kölling
 * 
 * @version 1.1
 */
public class Rocket extends SmoothMover
{
    private static final int gunReloadTime = 5;         // The minimum delay between firing the gun.

    private int reloadDelayCount;               // How long ago we fired the gun the last time.
    
    private GreenfootImage rocket = new GreenfootImage("rocket.png");    
    private GreenfootImage rocketWithThrust = new GreenfootImage("rocketWithThrust.png");

    /**
     * Initialise this rocket.
     */
    public Rocket()
    {
        reloadDelayCount = 5;
        addToVelocity(new Vector(13, 0.7));
    }

    /**
     * Do what a rocket's gotta do. (Which is: mostly flying about, and turning,
     * accelerating and shooting when the right keys are pressed.)
     * 9.29-The act method calls the checkCollision method.
     */
    public void act()
    {
        move();
        checkKeys();
        checkCollision();
        reloadDelayCount++;
    }
    
    /**
     * Check whether there are any key pressed and react to them.
     */
    private void checkKeys() 
    {
        ignite(Greenfoot.isKeyDown("up"));
        if (Greenfoot.isKeyDown("space")) 
        {
            fire();
        } else if (Greenfoot.isKeyDown("left")) {
            turn(-5);
        } else if (Greenfoot.isKeyDown("right")) {
            turn(5);
        } else if (Greenfoot.isKeyDown("z")) {
           startProtonWave();
        }

    }
    
    /**
     * Fire a bullet if the gun is ready.
     */
    private void fire() 
    {
        if (reloadDelayCount >= gunReloadTime) 
        {
            Bullet bullet = new Bullet (getVelocity(), getRotation());
            getWorld().addObject (bullet, getX(), getY());
            bullet.move ();
            reloadDelayCount = 0;
        }
    }
    
    private void ignite(boolean isKeyDown) 
    {
        if (isKeyDown) 
        {
            setImage(rocketWithThrust);
            addToVelocity(new Vector(getRotation(), 0.3));
        }
        else 
        {
            setImage(rocket);        
        }
    }
    
    
    // 9.28-This method checks if the rocket is colliding with an asteroid.
    // 9.32-The method would trigger an explosino and end the game if the rocket hits an asteroid.
    // 9.33-The if statement checks whether it contains any asteroids stored by getOneIntersectingObject.
    
    private void checkCollision() {
        // Asteroid a =(Asteroid) getOneIntersectingObject(Asteroid.class);
        // if (a != null) {
            // // Body of the if statement
            // Space space = (Space) getWorld();
            // space.addObject(new Explosion(), getX(), getY());
            // space.removeObject(this);
            // space.gameOver();
        // }
    }
    
    private void startProtonWave() {
        World world = getWorld();
        world.addObject(new ProtonWave(), getX(), getY());
    }
}